@@ -812,6 +812,13 @@ class PolyNation:
         self.population['planet'] = self.land.planet.name
         self.population['str_chromosome_ids'] = [str(ids) for ids in 
                                      self.population['chromosome_ids'].values]
+        # Drop zero columns
+        self.population = self.population.loc[:, (self.population != 0).any(
+            axis=0)]
+        # Readd zero columns if global ones removed
+        for col in self.land.planet.global_cols:
+            if col not in self.population.columns:
+                self.population[col] = 0
         # Can't add lists to database and don't want to save fitness or 
         # immigration location
         property_cols = [col for col in self.population.columns if col not 
